//
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

//  .NET StockTrader Sample WCF Application for Benchmarking, Performance Analysis and Design Considerations for Service-Oriented Applications

using System;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using Trade.StockTraderWebApplicationSettings;
using Trade.StockTraderWebApplicationServiceClient;
using Trade.StockTraderWebApplicationModelClasses;
using Trade.Utility;

namespace Trade.Web
{
    /// <summary>
    /// Displays orders via a repeater, used on Account.aspx page.
    /// </summary>
    public partial class AccountOrders : System.Web.UI.UserControl
    {
        public int totalOrders;
        public int ordersRequested;
        public TotalOrdersUI orderData;
            
        protected override void OnLoad(EventArgs e)
        {
            BSLClient businessServicesClient = new BSLClient();
            
            string userid = HttpContext.Current.User.Identity.Name;
            string action = Request.QueryString["action"] ?? string.Empty;
            
            if (action.Equals("showtoporders", StringComparison.InvariantCultureIgnoreCase)
                && Settings.interfaceMode != StockTraderUtility.ACCESS_WSAS_Http_WebService
                && Settings.interfaceMode != StockTraderUtility.ACCESS_PHP_Http_WebService)
            {
                ordersRequested = Settings.MAX_DISPLAY_TOP_ORDERS;
                orderData = businessServicesClient.getTopOrders(userid);
            }
            else
            {
                ordersRequested = Settings.MAX_DISPLAY_ORDERS;
                orderData = businessServicesClient.getOrders(userid);
            }
            if (orderData.orders.Count != 0)
            {
                AccountOrdersRepeater.DataSource = orderData.orders;
                AccountOrdersRepeater.DataBind();
            }
            totalOrders = orderData.orders.Count;
        }
    }
}